<?php

namespace Roshan\Roshan\Http\Controllers;

use App\Http\Controllers\AdminApiController as AdminController;
use Roshan\Roshan\Http\Requests\RoshanAdminApiRequest;
use Roshan\Roshan\Interfaces\RoshanRepositoryInterface;
use Roshan\Roshan\Models\Roshan;

/**
 * Admin API controller class.
 */
class RoshanAdminApiController extends AdminController
{
    /**
     * Initialize roshan controller.
     *
     * @param type RoshanRepositoryInterface $roshan
     *
     * @return type
     */
    public function __construct(RoshanRepositoryInterface $roshan)
    {
        $this->repository = $roshan;
        parent::__construct();
    }

    /**
     * Display a list of roshan.
     *
     * @return json
     */
    public function index(RoshanAdminApiRequest $request)
    {
        $roshans  = $this->repository
            ->setPresenter('\\Roshan\\Roshan\\Repositories\\Presenter\\RoshanListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $roshans['code'] = 2000;
        return response()->json($roshans) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display roshan.
     *
     * @param Request $request
     * @param Model   Roshan
     *
     * @return Json
     */
    public function show(RoshanAdminApiRequest $request, Roshan $roshan)
    {
        $roshan         = $roshan->presenter();
        $roshan['code'] = 2001;
        return response()->json($roshan)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new roshan.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(RoshanAdminApiRequest $request, Roshan $roshan)
    {
        $roshan         = $roshan->presenter();
        $roshan['code'] = 2002;
        return response()->json($roshan)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new roshan.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(RoshanAdminApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $roshan          = $this->repository->create($attributes);
            $roshan          = $roshan->presenter();
            $roshan['code']  = 2004;

            return response()->json($roshan)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
;
        }
    }

    /**
     * Show roshan for editing.
     *
     * @param Request $request
     * @param Model   $roshan
     *
     * @return json
     */
    public function edit(RoshanAdminApiRequest $request, Roshan $roshan)
    {
        $roshan         = $roshan->presenter();
        $roshan['code'] = 2003;
        return response()-> json($roshan)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the roshan.
     *
     * @param Request $request
     * @param Model   $roshan
     *
     * @return json
     */
    public function update(RoshanAdminApiRequest $request, Roshan $roshan)
    {
        try {

            $attributes = $request->all();

            $roshan->update($attributes);
            $roshan         = $roshan->presenter();
            $roshan['code'] = 2005;

            return response()->json($roshan)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the roshan.
     *
     * @param Request $request
     * @param Model   $roshan
     *
     * @return json
     */
    public function destroy(RoshanAdminApiRequest $request, Roshan $roshan)
    {

        try {

            $t = $roshan->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('roshan::roshan.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
