<?php

namespace Roshan\Roshan\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Roshan\Roshan\Models\Roshan;

class RoshanPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the roshan.
     *
     * @param User $user
     * @param Roshan $roshan
     *
     * @return bool
     */
    public function view(User $user, Roshan $roshan)
    {
        if ($user->canDo('roshan.roshan.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $roshan->user_id;
    }

    /**
     * Determine if the given user can create a roshan.
     *
     * @param User $user
     * @param Roshan $roshan
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('roshan.roshan.create');
    }

    /**
     * Determine if the given user can update the given roshan.
     *
     * @param User $user
     * @param Roshan $roshan
     *
     * @return bool
     */
    public function update(User $user, Roshan $roshan)
    {
        if ($user->canDo('roshan.roshan.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $roshan->user_id;
    }

    /**
     * Determine if the given user can delete the given roshan.
     *
     * @param User $user
     * @param Roshan $roshan
     *
     * @return bool
     */
    public function destroy(User $user, Roshan $roshan)
    {
        if ($user->canDo('roshan.roshan.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $roshan->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
